@@ -32,5 +32,5 @@ pub fn load_agent_conf(filename: &String) -> io::Result<ModConfStruct> {
             conf.active = value.parse().unwrap();
         }
     }
-    Ok(conf)
+    return Ok(conf);
 }
