@@ -29,7 +29,19 @@ pub fn send_request_json(json_value: Value) -> Result<(), ureq::Error> {
 pub fn mod_send_request_grpc(name: String, datetime: i64, content: String, conf_filename: String) {
     let mod_conf = mod_conf::load_mod_conf(&conf_filename.to_string()).unwrap();
 
-    let run_time = Builder::new_multi_thread().enable_all().build().unwrap();
+    let run_time = Builder::new_multi_thread()
+        .enable_all()
+        .worker_threads(2)
+        .thread_keep_alive(Duration::from_millis(1))
+        .max_blocking_threads(2)
+        .on_thread_start(|| {
+            println!("Mod to Agent Start!");
+        })
+        .on_thread_stop(|| {
+            println!("Mod to Agent Stop!");
+        })
+        .build()
+        .unwrap();
     run_time.block_on(async {
         let mut client = ZhiYanClient::connect(mod_conf.agent_url.clone())
             .await
@@ -44,11 +56,14 @@ pub fn mod_send_request_grpc(name: String, datetime: i64, content: String, conf_
         let response = client.zymod(request).await.unwrap();
         let upload_response = response.get_ref();
         println!(
-            "Code:{:?}\tMessages{:?}",
+            "Code:{:?}\nMessages{:?}\n+++++++++++++++++++++",
             upload_response.code, upload_response.message
         );
         thread::sleep(Duration::from_millis(mod_conf.interval.clone()));
     });
+    run_time.shutdown_timeout(Duration::from_millis(10));
+
+    return;
 }
 
 pub fn agent_send_request_grpc(
@@ -59,8 +74,7 @@ pub fn agent_send_request_grpc(
 ) {
     let agent_conf = agent_conf::load_agent_conf(&conf_filename.to_string()).unwrap();
 
-    let run_time = Builder::new_multi_thread().enable_all().build().unwrap();
-    run_time.spawn(async move {
+    tokio::spawn(async move {
         let mut client = ZhiYanClient::connect(agent_conf.server_url).await.unwrap();
 
         let request = Request::new(ZhiYanRequest {
@@ -68,10 +82,12 @@ pub fn agent_send_request_grpc(
             datetime: datetime.clone(),
             content: content.clone(),
         });
-
         let response = client.zymod(request).await.unwrap();
         let upload_response = response.get_ref();
-        println!("{:?}\n{:?}", upload_response.code, upload_response.message);
+        println!(
+            "{:?}\n{:?}\n+++++++++++++++++++++",
+            upload_response.code, upload_response.message
+        )
     });
-    std::mem::forget(run_time);
+    return;
 }
