@@ -36,5 +36,5 @@ pub fn load_mod_conf(filename: &String) -> io::Result<ModConfStruct> {
             conf.active = value.parse().unwrap();
         }
     }
-    Ok(conf)
+    return Ok(conf);
 }
